@@ -24,6 +24,11 @@ class directory {
 			// opens directory "path"
 		bool	close();
 			// closes the currently open directory
+
+		uint64_t	getChildCount();
+			// Returns the number of files/subdirectories inside
+			// the open directory.
+
 		char	*getChildName(uint64_t index);
 			// Returns the name of the file/subdirectory at "index".
 			//
@@ -31,6 +36,22 @@ class directory {
 			// returns it.  The calling program must deallocate the
 			// buffer.
 
+
+		int64_t	maxFileNameLength();
+			// Returns the length of the longest file name
+			// that can be created in directory "pathname".
+		int64_t	maxPathLength();
+			// Returns the length of the longest relative
+			// path name that can be created under the
+			// directory "pathname".
+		bool	canAccessLongFileNames();
+			// Returns true if an attempt to access a
+			// file in directory "pathname" longer than the
+			// length returned by maxFileNameLength() will
+			// succeed or false if it will fail.
+
+
+
 		static bool	create(const char *path, mode_t perms);
 				// creates a new directory "path" with 
 				// permissions "perms"
