@@ -12,11 +12,17 @@
 namespace rudiments {
 #endif
 
+class mutexprivate;
+
 class mutex {
 	public:
 			mutex();
 			// Initialize a mutex.
+			#if defined(HAVE_PTHREAD_MUTEX_T)
 			mutex(pthread_mutex_t *mut);
+			#elif defined(HAVE_CREATE_MUTEX)
+			mutex(HANDLE mut);
+			#endif
 			// Attach already initialized "mut" to this instance.
 			~mutex();
 			// Destroy the mutex.
@@ -33,7 +39,11 @@ class mutex {
 			// Unlock the mutex.
 			// Returns true on success and false if an error occurs.
 
+		#if defined(HAVE_PTHREAD_MUTEX_T)
 		pthread_mutex_t	*getMutex();
+		#elif defined(HAVE_CREATE_MUTEX)
+		HANDLE		getMutex();
+		#endif
 				// Returns the mutex used by
 				// the class internally.
 
