@@ -4,5 +4,5 @@
 #include <rudiments/dictionary.h>
 
 #ifdef RUDIMENTS_HAS_THREADS
-	#include <pthread.h>
+	#include <rudiments/mutex.h>
 #endif
