@@ -2,9 +2,12 @@
 // See the COPYING file for more information.
 
 	private:
-		void	*data;
-		size_t	length;
-
 		// FIXME: it should be possible to copy a memorymap
 				memorymap(const memorymap &m);
 		memorymap	&operator=(const memorymap &m);
+
+			bool	mAdvise(unsigned char *start,
+					size_t length, int advice);
+		static	bool	mLockAll(int flags);
+
+		memorymapprivate	*pvt;
