@@ -1,6 +1,6 @@
 // Copyright (c) 2005 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/private/config.h>
+#include <rudiments/private/inttypes.h>
 
 #include <sys/types.h>
