@@ -1,11 +1,11 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
-#include <rudiments/private/config.h>
+#include <rudiments/private/inttypes.h>
 
 #include <sys/types.h>
 #include <shadow.h>
 
 #ifdef RUDIMENTS_HAS_THREADS
-	#include <pthread.h>
+	#include <rudiments/mutex.h>
 #endif
