@@ -13,6 +13,8 @@
 namespace rudiments {
 #endif
 
+class serialportprivate;
+
 class serialport : public filedescriptor {
 	public:
 
@@ -51,6 +53,8 @@ class serialport : public filedescriptor {
 
 		bool	sendBreak(int duration);
 			// tcsendbreak()
+
+	#include <rudiments/private/serialport.h>
 };
 
 #ifdef RUDIMENTS_NAMESPACE
